## Reference
[Face Retrieval](https://github.com/gallardorafael/sentinel-face-retrieval/tree/dev)

[YOLO-Face](https://github.com/akanametov/yolo-face)

[Milvus : Vector DB](https://github.com/milvus-io/milvus)